@@ -207,6 +207,23 @@ if ($do==1) {
    ($stdout,$stderr)=$handle->cmd("mkdir -vp FullAutoAPI/deps",'__display__');
    ($stdout,$stderr)=$handle->cmd("mkdir -vp FullAutoAPI/root/static/images",
       '__display__');
+   ($stdout,$stderr)=$handle->cmd("perl -e \'use CPAN;".
+      "CPAN::HandleConfig-\>load;print \$CPAN::Config-\>{build_dir}\'");
+   my $builddir=$stdout;
+   my $fa_ver=$Net::FullAuto::VERSION;
+   ($stdout,$stderr)=$handle->cmd(
+      "ls -1t $stdout | grep Net-FullAuto-$fa_ver");
+   my @lstmp=split /\n/,$stdout;
+   my @ls_tmp=();
+   foreach my $line (@lstmp) {
+      unshift @ls_tmp, $line if $line!~/\.yml$/;
+   }
+   ($stdout,$stderr)=$handle->cmd("cp -v $builddir/$ls_tmp[0]/api/*jpg ".
+      "FullAutoAPI/root/static/images",'__display__');
+   ($stdout,$stderr)=$handle->cmd("cp -v $builddir/$ls_tmp[0]/api/*tt ".
+      "FullAutoAPI/root",'__display__');
+   ($stdout,$stderr)=$handle->cmd("cp -v $lddir/$ls_tmp[0]/demo/FA.ico ".
+      "FullAutoAPI/root/favicon.ico",'__display__');
    ($stdout,$stderr)=$handle->cwd("FullAutoAPI/deps");
    ($stdout,$stderr)=$handle->cmd(
       "wget --random-wait --progress=dot ".
@@ -568,7 +585,6 @@ END
             "${sudo}LD_LIBRARY_PATH=/usr/local/lib ".
             "PKG_CONFIG_PATH=/usr/local/lib/pkgconfig ".
             "LD_PRELOAD=/usr/local/lib/libzmq.so.5 ".
-            "LOCAL_FULLAUTOAPI_PATH=$userhome/FullAutoAPI ".
             "cpan -f -i $module",
             '__display__');
       } else {
